"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMediaQuery = exports.SIZES = void 0;
const react_1 = require("react");
var SIZES;
(function (SIZES) {
    SIZES["lg"] = "1024px";
    SIZES["md"] = "768px";
})(SIZES || (exports.SIZES = SIZES = {}));
const checkMinMatch = (size) => {
    const query = `(min-width: ${size})`;
    return window.matchMedia(query).matches;
};
const checkMaxMatch = (size) => {
    const query = `(max-width: ${size})`;
    return window.matchMedia(query).matches;
};
const useMediaQuery = ({ size }) => {
    const [isMinMatch, setIsMinMatch] = (0, react_1.useState)(false);
    const [isMaxMatch, setIsMaxMatch] = (0, react_1.useState)(false);
    const checkMatch = () => {
        setIsMinMatch(checkMinMatch(size));
        setIsMaxMatch(checkMaxMatch(size));
    };
    (0, react_1.useEffect)(() => {
        checkMatch();
        window.addEventListener('resize', checkMatch);
        return () => window.removeEventListener('resize', checkMatch);
    }, []);
    return {
        isMinMatch: isMinMatch !== null && isMinMatch !== void 0 ? isMinMatch : checkMinMatch(size),
        isMaxMatch: isMaxMatch !== null && isMaxMatch !== void 0 ? isMaxMatch : checkMaxMatch(size),
    };
};
exports.useMediaQuery = useMediaQuery;
